@@ -1,9 +1,11 @@
 use strict;
 use warnings;
 package MetaCPAN::API;
-# ABSTRACT: A comprehensive, DWIM-featured API to MetaCPAN
-$MetaCPAN::API::VERSION = '0.44';
-use Any::Moose;
+# ABSTRACT: A comprehensive, DWIM-featured API to MetaCPAN (DEPRECATED)
+$MetaCPAN::API::VERSION = '0.50';
+use Moo;
+use Types::Standard qw<Str ArrayRef InstanceOf>;
+use namespace::autoclean;
 
 use Carp;
 use JSON;
@@ -26,19 +28,20 @@ with qw/
 
 has base_url => (
     is      => 'ro',
-    isa     => 'Str',
-    default => 'http://api.metacpan.org/v0',
+    isa     => Str,
+    default => sub{'http://api.metacpan.org/v0'},
 );
 
 has ua => (
-    is         => 'ro',
-    isa        => 'HTTP::Tiny',
-    lazy_build => 1,
+    is  => 'ro',
+    lazy => 1,
+    builder => '_build_ua',
+    isa => InstanceOf['HTTP::Tiny'],
 );
 
 has ua_args => (
     is      => 'ro',
-    isa     => 'ArrayRef',
+    isa     => ArrayRef,
     default => sub {
         my $version = $MetaCPAN::API::VERSION || 'xx';
         return [ agent => "MetaCPAN::API/$version" ];
@@ -47,7 +50,6 @@ has ua_args => (
 
 sub _build_ua {
     my $self = shift;
-
     return HTTP::Tiny->new( @{ $self->ua_args } );
 }
 
@@ -142,13 +144,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
-MetaCPAN::API - A comprehensive, DWIM-featured API to MetaCPAN
+MetaCPAN::API - A comprehensive, DWIM-featured API to MetaCPAN (DEPRECATED)
 
 =head1 VERSION
 
-version 0.44
+version 0.50
 
 =head1 SYNOPSIS
 
@@ -176,53 +180,8 @@ version 0.44
 
 =head1 DESCRIPTION
 
-This is a hopefully-complete API-compliant interface to MetaCPAN
-(L<https://metacpan.org>) with DWIM capabilities, to make your life easier.
-
-This module has three purposes:
-
-=over 4
-
-=item * Provide 100% of the beta MetaCPAN API
-
-This module will be updated regularly on every MetaCPAN API change, and intends
-to provide the user with as much of the API as possible, no shortcuts. If it's
-documented in the API, you should be able to do it.
-
-Because of this design decision, this module has an official MetaCPAN namespace
-with the blessing of the MetaCPAN developers.
-
-Notice this module currently only provides the beta API, not the old
-soon-to-be-deprecated API.
-
-=item * Be lightweight, to allow flexible usage
-
-While many modules would help make writing easier, it's important to take into
-account how they affect your compile-time, run-time and overall memory
-consumption.
-
-By providing a slim interface implementation, more users are able to use this
-module, such as long-running processes (like daemons), CLI or GUI applications,
-cron jobs, and more.
-
-=item * DWIM
-
-While it's possible to access the methods defined by the API spec, there's still
-a matter of what you're really trying to achieve. For example, when searching
-for I<"Dave">, you want to find both I<Dave Cross> and I<Dave Rolsky> (and any
-other I<Dave>), but you also want to search for a PAUSE ID of I<DAVE>, if one
-exists.
-
-This is where DWIM comes in. This module provides you with additional generic
-methods which will try to do what they think you want.
-
-Of course, this does not prevent you from manually using the API methods. You
-still have full control over that, if that's what you wish.
-
-You can (and should) read up on the generic methods, which will explain how
-their DWIMish nature works, and what searches they run.
-
-=back
+This was the original hopefully-complete API-compliant interface to MetaCPAN
+(L<https://metacpan.org>).  It has now been superseded by L<MetaCPAN::Client>.
 
 =head1 DEPRECATED
 
