@@ -2,9 +2,10 @@ use strict;
 use warnings;
 package MetaCPAN::API::Module;
 # ABSTRACT: Module information for MetaCPAN::API
-$MetaCPAN::API::Module::VERSION = '0.44';
+$MetaCPAN::API::Module::VERSION = '0.50';
 use Carp;
-use Any::Moose 'Role';
+use Moo::Role;
+use namespace::autoclean;
 
 # /module/{module}
 sub module {
@@ -22,13 +23,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 MetaCPAN::API::Module - Module information for MetaCPAN::API
 
 =head1 VERSION
 
-version 0.44
+version 0.50
 
 =head1 DESCRIPTION
 
