@@ -2,9 +2,10 @@ use strict;
 use warnings;
 package MetaCPAN::API::POD;
 # ABSTRACT: POD information for MetaCPAN::API
-$MetaCPAN::API::POD::VERSION = '0.44';
+$MetaCPAN::API::POD::VERSION = '0.50';
 use Carp;
-use Any::Moose 'Role';
+use Moo::Role;
+use namespace::autoclean;
 
 # /pod/{module}
 # /pod/{author}/{release}/{path}
@@ -52,13 +53,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 MetaCPAN::API::POD - POD information for MetaCPAN::API
 
 =head1 VERSION
 
-version 0.44
+version 0.50
 
 =head1 DESCRIPTION
 
