@@ -2,9 +2,10 @@ use strict;
 use warnings;
 package MetaCPAN::API::Release;
 # ABSTRACT: Distribution and releases information for MetaCPAN::API
-$MetaCPAN::API::Release::VERSION = '0.44';
+$MetaCPAN::API::Release::VERSION = '0.50';
 use Carp;
-use Any::Moose 'Role';
+use Moo::Role;
+use namespace::autoclean;
 
 # /release/{distribution}
 # /release/{author}/{release}
@@ -45,13 +46,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 MetaCPAN::API::Release - Distribution and releases information for MetaCPAN::API
 
 =head1 VERSION
 
-version 0.44
+version 0.50
 
 =head1 DESCRIPTION
 
