@@ -2,9 +2,10 @@ use strict;
 use warnings;
 package MetaCPAN::API::Source;
 # ABSTRACT: Source information for MetaCPAN::API
-$MetaCPAN::API::Source::VERSION = '0.44';
+$MetaCPAN::API::Source::VERSION = '0.50';
 use Carp;
-use Any::Moose 'Role';
+use Moo::Role;
+use namespace::autoclean;
 
 # /source/{author}/{release}/{path}
 sub source {
@@ -40,13 +41,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 MetaCPAN::API::Source - Source information for MetaCPAN::API
 
 =head1 VERSION
 
-version 0.44
+version 0.50
 
 =head1 DESCRIPTION
 
